==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/es_EC.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given web address is not a valid URL" : "La dirección web proporcionada no es una URL válida",
    "The given legal notice address is too long" : "La dirección del aviso legal es demasiado larga",
    "The given legal notice address is not a valid URL" : "La dirección de aviso legal proporcionada no es una URL válida",
    "The given privacy policy address is too long" : "La dirección de política de privacidad proporcionada es demasiado larga",
    "The given privacy policy address is not a valid URL" : "La dirección de política de privacidad proporcionada no es una URL válida",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "Disable-user-theming should be true or false" : "disable-user-theming debe ser verdadero (true) o falso (false)",
    "Saved" : "Guardado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya te encuentras usando un tema personalizado. La aplicación de Temas puede estar siendo sobreescrita por él.",
    "Theming" : "Tematizar",
    "Appearance and accessibility" : "Apariencia y accesibilidad",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "No se ha habilitado el módulo PHP \"imagick\", aunque está habilitada la aplicación de temas. Para que la generación de favicon funcione correctamente, debe instalar y habilitar este módulo.",
    "Dark theme with high contrast mode" : "Tema oscuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar el modo oscuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Similar al modo de alto contraste, pero con colores oscuros.",
    "Dark theme" : "Tema Oscuro",
    "Enable dark theme" : "Activar Tema Oscuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema oscuro que facilita la vista al reducir la luminosidad y el brillo general.",
    "System default theme" : "Tema predeterminado del sistema",
    "Enable the system default" : "Activar la apariencia predeterminada del sistema",
    "Using the default system appearance." : "Usar la apariencia predeterminada del sistema.",
    "Dyslexia font" : "Fuente dislexia",
    "Enable dyslexia font" : "Habilitar Fuente dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra / fuente gratuito diseñado para mitigar algunos de los errores de lectura comunes causados por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Habilitar el modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar su navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar el tema claro predeterminado",
    "The default light appearance." : "La apariencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajustar el tema de Nextcloud",
    "Name" : "Nombre",
    "Web link" : "Enlace web",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Slogan" : "Lema",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Header logo" : "Logo del encabezado",
    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Cargar un nuevo favicon",
    "User settings" : "Configuración de usuario",
    "Disable user theming" : "Deshabilitar la personalización del usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puedes seleccionar y personalizar tu instancia, los usuarios pueden cambiar su fondo y colores. Si deseas aplicar tu personalización, puedes activar esta opción.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Logo" : "Logotipo",
    "Upload new background and login image" : "Cargar nueva imagen de fondo y de inicio de sesión",
    "Background and login image" : "Imagen de fondo y de inicio de sesión",
    "Advanced options" : "Opciones avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP ImageMagick con soporte para imágenes SVG para generar automáticamente los favicons basados en el logotipo y color cargados.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras algún problema, no dudes en informarlo en {issuetracker}nuestro sistema de seguimiento de problemas{linkend}. ¡Y si quieres participar, únete a {designteam}nuestro equipo de diseño{linkend}!",
    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por tu administrador",
    "Keyboard shortcuts" : "Atajos del teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. Para permitir el enfoque correcto en tu herramienta, puedes desactivar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
    "Move up" : "Mover hacia arriba",
    "Move down" : "Mover hacia abajo",
    "Select a background from your files" : "Selecciona un fondo de tus archivos",
    "Custom background" : "Fondo personalizado",
    "Plain background" : "Fondo simple",
    "Default background" : "Fondo predeterminado",
    "Theme selection is enforced" : "La selección de temas es obligatoria",
    "Select a custom color" : "Seleccionar un color personalizado",
    "Reset to default" : "Restablecer al predeterminado",
    "Upload" : "Cargar",
    "Remove background image" : "Eliminar imagen de fondo",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo sea utilizable también sin mouse y software de asistencia, como lectores de pantalla. Nuestro objetivo es cumplir con las {guidelines} Directrices de accesibilidad al contenido web {linkend} 2.1 en el nivel AA, con el tema de alto contraste incluso en el nivel AAA."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/es_EC.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given web address is not a valid URL" : "La dirección web proporcionada no es una URL válida",
    "The given legal notice address is too long" : "La dirección del aviso legal es demasiado larga",
    "The given legal notice address is not a valid URL" : "La dirección de aviso legal proporcionada no es una URL válida",
    "The given privacy policy address is too long" : "La dirección de política de privacidad proporcionada es demasiado larga",
    "The given privacy policy address is not a valid URL" : "La dirección de política de privacidad proporcionada no es una URL válida",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "Saved" : "Guardado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya te encuentras usando un tema personalizado. La aplicación de Temas puede estar siendo sobreescrita por él.",
    "Theming" : "Tematizar",
    "Appearance and accessibility" : "Apariencia y accesibilidad",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "No se ha habilitado el módulo PHP \"imagick\", aunque está habilitada la aplicación de temas. Para que la generación de favicon funcione correctamente, debe instalar y habilitar este módulo.",
    "Dark theme with high contrast mode" : "Tema oscuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar el modo oscuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Similar al modo de alto contraste, pero con colores oscuros.",
    "Dark theme" : "Tema Oscuro",
    "Enable dark theme" : "Activar Tema Oscuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema oscuro que facilita la vista al reducir la luminosidad y el brillo general.",
    "System default theme" : "Tema predeterminado del sistema",
    "Enable the system default" : "Activar la apariencia predeterminada del sistema",
    "Using the default system appearance." : "Usar la apariencia predeterminada del sistema.",
    "Dyslexia font" : "Fuente dislexia",
    "Enable dyslexia font" : "Habilitar Fuente dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra / fuente gratuito diseñado para mitigar algunos de los errores de lectura comunes causados por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Habilitar el modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar su navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar el tema claro predeterminado",
    "The default light appearance." : "La apariencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajustar el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Web link" : "Enlace web",
    "Slogan" : "Lema",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Remove background image" : "Eliminar imagen de fondo",
    "Favicon" : "Favicon",
    "Logo" : "Logotipo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puedes seleccionar y personalizar tu instancia, los usuarios pueden cambiar su fondo y colores. Si deseas aplicar tu personalización, puedes activar esta opción.",
    "Disable user theming" : "Deshabilitar la personalización del usuario",
    "Move up" : "Mover hacia arriba",
    "Move down" : "Mover hacia abajo",
    "Theme selection is enforced" : "La selección de temas es obligatoria",
    "Select a background from your files" : "Selecciona un fondo de tus archivos",
    "Custom background" : "Fondo personalizado",
    "Plain background" : "Fondo simple",
    "Default background" : "Fondo predeterminado",
    "Keyboard shortcuts" : "Atajos del teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. Para permitir el enfoque correcto en tu herramienta, puedes desactivar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
    "Reset to default" : "Restablecer al predeterminado",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras algún problema, no dudes en informarlo en {issuetracker}nuestro sistema de seguimiento de problemas{linkend}. ¡Y si quieres participar, únete a {designteam}nuestro equipo de diseño{linkend}!",
    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por tu administrador",
    "Disable-user-theming should be true or false" : "disable-user-theming debe ser verdadero (true) o falso (false)",
    "Header logo" : "Logo del encabezado",
    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
    "Upload new favicon" : "Cargar un nuevo favicon",
    "User settings" : "Configuración de usuario",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Upload new background and login image" : "Cargar nueva imagen de fondo y de inicio de sesión",
    "Background and login image" : "Imagen de fondo y de inicio de sesión",
    "Advanced options" : "Opciones avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP ImageMagick con soporte para imágenes SVG para generar automáticamente los favicons basados en el logotipo y color cargados.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo sea utilizable también sin mouse y software de asistencia, como lectores de pantalla. Nuestro objetivo es cumplir con las {guidelines} Directrices de accesibilidad al contenido web {linkend} 2.1 en el nivel AA, con el tema de alto contraste incluso en el nivel AAA.",
    "Select a custom color" : "Seleccionar un color personalizado",
    "Upload" : "Cargar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
